@@ -51,6 +51,8 @@ public:
   Q_INVOKABLE bool setTextType(int index);
   Q_INVOKABLE int textType() const;
 
+  Q_INVOKABLE bool hasBasmala(int sura);
+
   Page pageFromIndex(int index) const;
 
   Page pageForSura(int sura) const;
@@ -59,7 +61,7 @@ public:
 
   Sura sura(int index) const;
 
-  QString basmala() const;
+  Q_INVOKABLE QString basmala() const;
 
   QString prefix() const;
 
@@ -67,7 +69,7 @@ public:
 
   QStringList text(const Fragment& frag) const;
   QStringList secondaryText(const Fragment& frag) const;
-  QString secondaryText(int sura, int aya);
+  Q_INVOKABLE QString secondaryText(int sura, int aya);
 
   void setSecondaryText(TextProvider *text);
 
